searchData={"items":[{"type":"module","title":"Delimit","doc":"Delimit: A library for defining and working with delimited data files.\n\nDelimit allows you to define a schema for delimited data files (CSV, TSV, etc.)\nand provides functions for reading, writing, and manipulating that data.\nThe library automatically generates structs based on your schema definition,\ncomplete with proper typespecs.","ref":"Delimit.html"},{"type":"module","title":"Example - Delimit","doc":"defmodule MyApp.Person do\n      use Delimit\n\n      layout do\n        field :first_name, :string\n        field :last_name, :string\n        field :age, :integer\n        field :birthday, :date, format: \"YYYY-MM-DD\"\n        field :active, :boolean\n      end\n    end\n\n    # Read data from a file (auto-detects CSV format)\n    people = MyApp.Person.read(\"people.csv\")\n    \n    # Read data with explicit format (tab-separated values)\n    people = MyApp.Person.read(\"people.tsv\", format: :tsv)\n\n    # Write data to a file\n    MyApp.Person.write(\"new_people.csv\", people)\n    \n    # Write data with explicit format (pipe-separated values)\n    MyApp.Person.write(\"new_people.psv\", people, format: :psv)\n\n    # Work with a specific record\n    first_person = Enum.at(people, 0)\n    IO.puts(\"Name: #{first_person.first_name} #{first_person.last_name}\")","ref":"Delimit.html#module-example"},{"type":"macro","title":"Delimit.embeds_one/2","doc":"Defines an embedded schema.","ref":"Delimit.html#embeds_one/2"},{"type":"macro","title":"Parameters - Delimit.embeds_one/2","doc":"* `name` - The name for the embedded schema\n  * `module` - The module defining the embedded schema","ref":"Delimit.html#embeds_one/2-parameters"},{"type":"macro","title":"Example - Delimit.embeds_one/2","doc":"embeds_one :address, MyApp.Address\n    embeds_one :billing_address, MyApp.Address, prefix: \"billing\"","ref":"Delimit.html#embeds_one/2-example"},{"type":"macro","title":"Delimit.embeds_one/3","doc":"Defines an embedded schema with options.","ref":"Delimit.html#embeds_one/3"},{"type":"macro","title":"Parameters - Delimit.embeds_one/3","doc":"* `name` - The name for the embedded schema\n  * `module` - The module defining the embedded schema\n  * `opts` - Options for the embedded schema","ref":"Delimit.html#embeds_one/3-parameters"},{"type":"macro","title":"Options - Delimit.embeds_one/3","doc":"* `:prefix` - Prefix to add to field headers (default: field name + \"_\")","ref":"Delimit.html#embeds_one/3-options"},{"type":"macro","title":"Example - Delimit.embeds_one/3","doc":"embeds_one :address, MyApp.Address, prefix: \"addr_\"","ref":"Delimit.html#embeds_one/3-example"},{"type":"macro","title":"Delimit.field/2","doc":"Defines a field in the schema.","ref":"Delimit.html#field/2"},{"type":"macro","title":"Parameters - Delimit.field/2","doc":"* `name` - The name of the field as atom\n  * `type` - The data type of the field (:string, :integer, :float, etc.)","ref":"Delimit.html#field/2-parameters"},{"type":"macro","title":"Example - Delimit.field/2","doc":"field :first_name, :string","ref":"Delimit.html#field/2-example"},{"type":"macro","title":"Delimit.field/3","doc":"Defines a field in the schema with options.","ref":"Delimit.html#field/3"},{"type":"macro","title":"Parameters - Delimit.field/3","doc":"* `name` - The name of the field as atom\n  * `type` - The data type of the field (:string, :integer, :float, etc.)\n  * `opts` - Options for the field","ref":"Delimit.html#field/3-parameters"},{"type":"macro","title":"Options - Delimit.field/3","doc":"* `:format` - Format string for date/time fields\n  * `:default` - Default value if the field is missing\n  * `:nil_on_empty` - If true, empty strings become nil (default: true)\n  * `:true_values` - List of values to interpret as true for boolean fields\n  * `:false_values` - List of values to interpret as false for boolean fields\n  * `:read_fn` - Custom function to parse the raw field value\n  * `:write_fn` - Custom function to convert the field value to string\n  * `:label` - Custom header label for this field (instead of the field name)\n  * `:struct_type` - The type to use in the struct (different from file type)","ref":"Delimit.html#field/3-options"},{"type":"macro","title":"Example - Delimit.field/3","doc":"field :birthday, :date, format: \"YYYY-MM-DD\"\n    field :active, :boolean, true_values: [\"Y\", \"YES\"], false_values: [\"N\", \"NO\"]\n    field :email, :string, label: \"contact_email\"\n    field :tags, :string, read_fn: &split_tags/1, write_fn: &join_tags/1, struct_type: {:list, :string}","ref":"Delimit.html#field/3-example"},{"type":"macro","title":"Delimit.layout/1","doc":"Defines the layout of a delimited file.","ref":"Delimit.html#layout/1"},{"type":"macro","title":"Example - Delimit.layout/1","doc":"layout do\n      field :first_name, :string\n      field :last_name, :string\n      field :age, :integer\n    end","ref":"Delimit.html#layout/1-example"},{"type":"module","title":"Delimit.Field","doc":"Defines field types, options, and conversion functions for Delimit schemas.\n\nThis module handles field definitions, data type conversions, and validation\nfor delimited data format parsing and generation.","ref":"Delimit.Field.html"},{"type":"type","title":"Delimit.Field.boolean_opts/0","doc":"Boolean field configuration options.","ref":"Delimit.Field.html#t:boolean_opts/0"},{"type":"type","title":"Delimit.Field.date_opts/0","doc":"Date field configuration options.","ref":"Delimit.Field.html#t:date_opts/0"},{"type":"type","title":"Delimit.Field.field_opts/0","doc":"General field configuration options.\n\n* `:optional` - Whether the field is optional (default: false)\n* `:default` - Default value if the field is missing\n* `:read_fn` - Custom function to parse the raw field value\n* `:write_fn` - Custom function to convert the field value to string\n* `:nil_on_empty` - If true, empty strings become nil (default: true)\n* `:label` - Custom header label for this field (instead of the field name)\n* `:struct_type` - The type to use in the struct (different from file type)","ref":"Delimit.Field.html#t:field_opts/0"},{"type":"type","title":"Delimit.Field.field_type/0","doc":"Supported field types.\n\nBasic field types:\n* `:string` - String values\n* `:integer` - Integer values\n* `:float` - Floating point values\n* `:boolean` - Boolean values\n* `:date` - Date values\n* `:datetime` - DateTime values\n* `:embed` - Embedded struct\n\nComplex type annotations (for `struct_type` option):\n* `{:list, inner_type}` - A list where each element is of type `inner_type`\n* `{:map, key_type, value_type}` - A map with keys of `key_type` and values of `value_type`\n* `{:map, value_type}` - A map with atom keys and values of `value_type`","ref":"Delimit.Field.html#t:field_type/0"},{"type":"function","title":"Delimit.Field.new/3","doc":"Creates a new field definition.","ref":"Delimit.Field.html#new/3"},{"type":"function","title":"Parameters - Delimit.Field.new/3","doc":"* `name` - The name of the field as an atom\n  * `type` - The type of the field (`:string`, `:integer`, etc.)\n  * `opts` - A keyword list of options for the field","ref":"Delimit.Field.html#new/3-parameters"},{"type":"function","title":"Example - Delimit.Field.new/3","doc":"iex> Delimit.Field.new(:first_name, :string, [])\n    %Delimit.Field{name: :first_name, type: :string, opts: []}\n\n    iex> Delimit.Field.new(:age, :integer, [default: 0])\n    %Delimit.Field{name: :age, type: :integer, opts: [default: 0]}","ref":"Delimit.Field.html#new/3-example"},{"type":"function","title":"Delimit.Field.parse_value/2","doc":"Parses a raw string value into the specified type.","ref":"Delimit.Field.html#parse_value/2"},{"type":"function","title":"Parameters - Delimit.Field.parse_value/2","doc":"* `value` - The raw string value from the delimited file\n  * `field` - The field definition","ref":"Delimit.Field.html#parse_value/2-parameters"},{"type":"function","title":"Returns - Delimit.Field.parse_value/2","doc":"* The parsed value or nil if the value is empty and nil_on_empty is true","ref":"Delimit.Field.html#parse_value/2-returns"},{"type":"function","title":"Example - Delimit.Field.parse_value/2","doc":"iex> field = Delimit.Field.new(:age, :integer)\n    iex> Delimit.Field.parse_value(\"42\", field)\n    42\n\n    iex> field = Delimit.Field.new(:active, :boolean)\n    iex> Delimit.Field.parse_value(\"Yes\", field)\n    true","ref":"Delimit.Field.html#parse_value/2-example"},{"type":"type","title":"Delimit.Field.t/0","doc":"Field definition structure.\n\n* `:name` - The name of the field\n* `:type` - The data type of the field\n* `:opts` - Additional options for the field","ref":"Delimit.Field.html#t:t/0"},{"type":"function","title":"Delimit.Field.to_string/2","doc":"Converts a value to a string representation for writing to a delimited file.","ref":"Delimit.Field.html#to_string/2"},{"type":"function","title":"Parameters - Delimit.Field.to_string/2","doc":"* `value` - The value to convert\n  * `field` - The field definition","ref":"Delimit.Field.html#to_string/2-parameters"},{"type":"function","title":"Returns - Delimit.Field.to_string/2","doc":"* The string representation of the value","ref":"Delimit.Field.html#to_string/2-returns"},{"type":"function","title":"Example - Delimit.Field.to_string/2","doc":"iex> field = Delimit.Field.new(:age, :integer)\n    iex> Delimit.Field.to_string(42, field)\n    \"42\"\n\n    iex> field = Delimit.Field.new(:active, :boolean)\n    iex> Delimit.Field.to_string(true, field)\n    \"true\"","ref":"Delimit.Field.html#to_string/2-example"},{"type":"module","title":"Delimit.Formats","doc":"Standard format configurations for common delimited file types.\n\nThis module provides predefined format configurations for common file formats\nsuch as CSV (comma-separated values), TSV (tab-separated values),\nPSV (pipe-separated values), and SSV (semi-colon separated values).\n\nUsing these formats simplifies configuration by setting appropriate defaults\nfor delimiter, escape character, and other format-specific options.","ref":"Delimit.Formats.html"},{"type":"function","title":"Delimit.Formats.get_options/1","doc":"Returns configuration options for a specified file format.","ref":"Delimit.Formats.html#get_options/1"},{"type":"function","title":"Parameters - Delimit.Formats.get_options/1","doc":"* `format` - The format identifier (`:csv`, `:tsv`, `:psv`)","ref":"Delimit.Formats.html#get_options/1-parameters"},{"type":"function","title":"Returns - Delimit.Formats.get_options/1","doc":"* A keyword list of options appropriate for the specified format","ref":"Delimit.Formats.html#get_options/1-returns"},{"type":"function","title":"Examples - Delimit.Formats.get_options/1","doc":"iex> Delimit.Formats.get_options(:csv)\n    [delimiter: \",\", escape: \"\"\"]\n\n    iex> Delimit.Formats.get_options(:tsv)\n    [delimiter: \"\\t\", escape: \"\"\"]","ref":"Delimit.Formats.html#get_options/1-examples"},{"type":"function","title":"Delimit.Formats.merge_options/3","doc":"Merges format options with custom options.\n\nFormat options take precedence over schema defaults but are overridden by\nexplicitly provided custom options.","ref":"Delimit.Formats.html#merge_options/3"},{"type":"function","title":"Parameters - Delimit.Formats.merge_options/3","doc":"* `schema_options` - Base options from the schema\n  * `format` - The format identifier, or nil for no format\n  * `custom_options` - Custom options that will override format options","ref":"Delimit.Formats.html#merge_options/3-parameters"},{"type":"function","title":"Returns - Delimit.Formats.merge_options/3","doc":"* A keyword list of merged options","ref":"Delimit.Formats.html#merge_options/3-returns"},{"type":"function","title":"Examples - Delimit.Formats.merge_options/3","doc":"iex> schema_opts = [trim_fields: false]\n    iex> Delimit.Formats.merge_options(schema_opts, :csv, [escape: \"'\"])\n    [trim_fields: false, delimiter: \",\", escape: \"'\"]","ref":"Delimit.Formats.html#merge_options/3-examples"},{"type":"function","title":"Delimit.Formats.supported_formats/0","doc":"Lists all supported format identifiers.","ref":"Delimit.Formats.html#supported_formats/0"},{"type":"function","title":"Returns - Delimit.Formats.supported_formats/0","doc":"* A list of supported format atoms","ref":"Delimit.Formats.html#supported_formats/0-returns"},{"type":"function","title":"Examples - Delimit.Formats.supported_formats/0","doc":"iex> Delimit.Formats.supported_formats()\n    [:csv, :tsv, :psv, :ssv]","ref":"Delimit.Formats.html#supported_formats/0-examples"},{"type":"module","title":"Delimit.Parsers","doc":"Pre-defined CSV parsers for common delimiters.\n\nThis module defines optimized parsers for common delimiters to avoid\ncreating new parser modules for each parsing operation.","ref":"Delimit.Parsers.html"},{"type":"function","title":"Delimit.Parsers.get_parser/2","doc":"Gets the appropriate parser for the given delimiter.","ref":"Delimit.Parsers.html#get_parser/2"},{"type":"function","title":"Parameters - Delimit.Parsers.get_parser/2","doc":"* `delimiter` - The delimiter character (comma, tab, etc.)\n  * `opts` - Parser options (reserved for future use)","ref":"Delimit.Parsers.html#get_parser/2-parameters"},{"type":"function","title":"Returns - Delimit.Parsers.get_parser/2","doc":"* A module that implements NimbleCSV parser functions","ref":"Delimit.Parsers.html#get_parser/2-returns"},{"type":"function","title":"Examples - Delimit.Parsers.get_parser/2","doc":"iex> Delimit.Parsers.get_parser(\",\")\n    DelimitCommaParser\n\n    iex> Delimit.Parsers.get_parser(\";\")\n    DelimitSemicolonParser","ref":"Delimit.Parsers.html#get_parser/2-examples"},{"type":"function","title":"Delimit.Parsers.get_parser_with_escape/3","doc":"Gets a parser with custom escape character.","ref":"Delimit.Parsers.html#get_parser_with_escape/3"},{"type":"function","title":"Parameters - Delimit.Parsers.get_parser_with_escape/3","doc":"* `delimiter` - The delimiter character (comma, tab, etc.)\n  * `escape` - The escape character (default: double-quote)\n  * `opts` - Additional options (reserved for future use)","ref":"Delimit.Parsers.html#get_parser_with_escape/3-parameters"},{"type":"function","title":"Returns - Delimit.Parsers.get_parser_with_escape/3","doc":"* A module that implements NimbleCSV parser functions","ref":"Delimit.Parsers.html#get_parser_with_escape/3-returns"},{"type":"function","title":"Examples - Delimit.Parsers.get_parser_with_escape/3","doc":"iex> Delimit.Parsers.get_parser_with_escape(\",\", \"'\")\n    # Returns a dynamically generated parser module","ref":"Delimit.Parsers.html#get_parser_with_escape/3-examples"},{"type":"module","title":"Delimit.Reader","doc":"Functions for reading delimited data from files or strings.\n\nThis module provides functionality to read delimited data from files\nor strings based on schema definitions, supporting both single-read\nand streaming operations.","ref":"Delimit.Reader.html"},{"type":"function","title":"Delimit.Reader.read_file/3","doc":"Reads delimited data from a file.","ref":"Delimit.Reader.html#read_file/3"},{"type":"function","title":"Parameters - Delimit.Reader.read_file/3","doc":"* `schema` - The schema definition\n  * `path` - Path to the delimited file\n  * `opts` - Read options that override schema options","ref":"Delimit.Reader.html#read_file/3-parameters"},{"type":"function","title":"Returns - Delimit.Reader.read_file/3","doc":"* List of structs with parsed data based on schema","ref":"Delimit.Reader.html#read_file/3-returns"},{"type":"function","title":"Examples - Delimit.Reader.read_file/3","doc":"iex> MyApp.Person.read(\"people.csv\")\n    [%MyApp.Person{first_name: \"John\", last_name: \"Doe\", age: 42}, ...]\n\n    iex> MyApp.Person.read(\"people.tsv\", format: :tsv)\n    [%MyApp.Person{first_name: \"John\", last_name: \"Doe\", age: 42}, ...]","ref":"Delimit.Reader.html#read_file/3-examples"},{"type":"type","title":"Delimit.Reader.read_options/0","doc":"Options for reading delimited data.\n\n* `:delimiter` - The field delimiter character (default: comma)\n* `:escape` - The escape character used for quotes (default: double-quote)\n* `:header` - Does the file contain a header? (default: false)\n* `:skip_lines` - Number of lines to skip at the beginning (default: 0)\n* `:skip_while` - Function that returns true for lines to skip\n* `:trim_fields` - Whether to trim whitespace from fields (default: true)\n* `:nil_on_empty` - Convert empty strings to nil (default: true)\n* `:format` - Predefined format (`:csv`, `:tsv`, `:psv`) that sets appropriate options","ref":"Delimit.Reader.html#t:read_options/0"},{"type":"function","title":"Delimit.Reader.read_string/3","doc":"Reads delimited data from a string.","ref":"Delimit.Reader.html#read_string/3"},{"type":"function","title":"Parameters - Delimit.Reader.read_string/3","doc":"* `schema` - The schema definition\n  * `string` - String containing delimited data\n  * `opts` - Read options that override schema options","ref":"Delimit.Reader.html#read_string/3-parameters"},{"type":"function","title":"Returns - Delimit.Reader.read_string/3","doc":"* List of structs with parsed data based on schema","ref":"Delimit.Reader.html#read_string/3-returns"},{"type":"function","title":"Examples - Delimit.Reader.read_string/3","doc":"iex> csv_data = \"first_name,last_name,age\\nJohn,Doe,42\"\n    iex> MyApp.Person.read_string(csv_data)\n    [%MyApp.Person{first_name: \"John\", last_name: \"Doe\", age: 42}]\n\n    iex> tsv_data = \"first_name\\tlast_name\\tage\\nJohn\\tDoe\\t42\"\n    iex> MyApp.Person.read_string(tsv_data, format: :tsv)\n    [%MyApp.Person{first_name: \"John\", last_name: \"Doe\", age: 42}]","ref":"Delimit.Reader.html#read_string/3-examples"},{"type":"function","title":"Delimit.Reader.stream_file/3","doc":"Streams delimited data from a file.","ref":"Delimit.Reader.html#stream_file/3"},{"type":"function","title":"Parameters - Delimit.Reader.stream_file/3","doc":"* `schema` - The schema definition\n  * `path` - Path to the delimited file\n  * `opts` - Read options that override schema options","ref":"Delimit.Reader.html#stream_file/3-parameters"},{"type":"function","title":"Returns - Delimit.Reader.stream_file/3","doc":"* Stream of structs with parsed data based on schema","ref":"Delimit.Reader.html#stream_file/3-returns"},{"type":"function","title":"Examples - Delimit.Reader.stream_file/3","doc":"iex> MyApp.Person.stream(\"large_people_file.csv\")\n    iex> |> Stream.take(10)\n    iex> |> Enum.to_list()\n    [%MyApp.Person{first_name: \"John\", last_name: \"Doe\", age: 42}, ...]\n\n    iex> MyApp.Person.stream(\"large_people_file.tsv\", format: :tsv)\n    iex> |> Stream.take(10)\n    iex> |> Enum.to_list()\n    [%MyApp.Person{first_name: \"John\", last_name: \"Doe\", age: 42}, ...]","ref":"Delimit.Reader.html#stream_file/3-examples"},{"type":"module","title":"Delimit.Schema","doc":"Defines schema structures and functions for working with delimited data.\n\nThis module handles schema definitions, data type conversions, and transformations\nbetween delimited data and Elixir structs.","ref":"Delimit.Schema.html"},{"type":"function","title":"Delimit.Schema.add_embed/4","doc":"Adds an embedded schema to the parent schema.","ref":"Delimit.Schema.html#add_embed/4"},{"type":"function","title":"Parameters - Delimit.Schema.add_embed/4","doc":"* `schema` - The parent schema to add the embedded schema to\n  * `name` - The name for the embedded schema as an atom\n  * `module` - The module defining the embedded schema\n  * `opts` - Options for the embedded schema","ref":"Delimit.Schema.html#add_embed/4-parameters"},{"type":"function","title":"Returns - Delimit.Schema.add_embed/4","doc":"* Updated schema structure","ref":"Delimit.Schema.html#add_embed/4-returns"},{"type":"function","title":"Delimit.Schema.add_field/4","doc":"Adds a field to the schema.","ref":"Delimit.Schema.html#add_field/4"},{"type":"function","title":"Parameters - Delimit.Schema.add_field/4","doc":"* `schema` - The schema to add the field to\n  * `name` - The name of the field as an atom\n  * `type` - The type of the field (:string, :integer, etc.)\n  * `opts` - Options for the field","ref":"Delimit.Schema.html#add_field/4-parameters"},{"type":"function","title":"Returns - Delimit.Schema.add_field/4","doc":"* Updated schema structure","ref":"Delimit.Schema.html#add_field/4-returns"},{"type":"function","title":"Delimit.Schema.field_names/1","doc":"Gets field names in order of definition.","ref":"Delimit.Schema.html#field_names/1"},{"type":"function","title":"Parameters - Delimit.Schema.field_names/1","doc":"* `schema` - The schema definition","ref":"Delimit.Schema.html#field_names/1-parameters"},{"type":"function","title":"Returns - Delimit.Schema.field_names/1","doc":"* List of field names as atoms","ref":"Delimit.Schema.html#field_names/1-returns"},{"type":"function","title":"Delimit.Schema.get_embed_prefix/2","doc":"Gets the header prefix for an embedded field.","ref":"Delimit.Schema.html#get_embed_prefix/2"},{"type":"function","title":"Parameters - Delimit.Schema.get_embed_prefix/2","doc":"* `field` - The embedded field definition\n  * `default_prefix` - Default prefix to use if none specified","ref":"Delimit.Schema.html#get_embed_prefix/2-parameters"},{"type":"function","title":"Returns - Delimit.Schema.get_embed_prefix/2","doc":"* String prefix to use for field headers","ref":"Delimit.Schema.html#get_embed_prefix/2-returns"},{"type":"function","title":"Delimit.Schema.get_embeds/1","doc":"Gets all embedded fields defined in the schema.","ref":"Delimit.Schema.html#get_embeds/1"},{"type":"function","title":"Parameters - Delimit.Schema.get_embeds/1","doc":"* `schema` - The schema definition","ref":"Delimit.Schema.html#get_embeds/1-parameters"},{"type":"function","title":"Returns - Delimit.Schema.get_embeds/1","doc":"* List of embedded field definitions","ref":"Delimit.Schema.html#get_embeds/1-returns"},{"type":"function","title":"Delimit.Schema.get_field/2","doc":"Gets a field by name.","ref":"Delimit.Schema.html#get_field/2"},{"type":"function","title":"Parameters - Delimit.Schema.get_field/2","doc":"* `schema` - The schema definition\n  * `name` - The field name to find","ref":"Delimit.Schema.html#get_field/2-parameters"},{"type":"function","title":"Returns - Delimit.Schema.get_field/2","doc":"* The field definition or nil if not found","ref":"Delimit.Schema.html#get_field/2-returns"},{"type":"function","title":"Delimit.Schema.headers/2","doc":"Gets the headers for the schema.","ref":"Delimit.Schema.html#headers/2"},{"type":"function","title":"Parameters - Delimit.Schema.headers/2","doc":"* `schema` - The schema definition\n  * `prefix` - Optional prefix to apply to all headers","ref":"Delimit.Schema.html#headers/2-parameters"},{"type":"function","title":"Returns - Delimit.Schema.headers/2","doc":"* List of header strings","ref":"Delimit.Schema.html#headers/2-returns"},{"type":"function","title":"Example - Delimit.Schema.headers/2","doc":"iex> schema = Delimit.Schema.new(MyApp.Person)\n    iex> schema = Delimit.Schema.add_field(schema, :name, :string)\n    iex> schema = Delimit.Schema.add_field(schema, :age, :integer)\n    iex> Delimit.Schema.headers(schema)\n    [\"name\", \"age\"]\n    \n    iex> Delimit.Schema.headers(schema, \"person_\")\n    [\"person_name\", \"person_age\"]","ref":"Delimit.Schema.html#headers/2-example"},{"type":"function","title":"Delimit.Schema.new/2","doc":"Creates a new schema definition.","ref":"Delimit.Schema.html#new/2"},{"type":"function","title":"Parameters - Delimit.Schema.new/2","doc":"* `module` - The module associated with the schema\n  * `options` - Options for the schema","ref":"Delimit.Schema.html#new/2-parameters"},{"type":"function","title":"Returns - Delimit.Schema.new/2","doc":"* A new schema structure","ref":"Delimit.Schema.html#new/2-returns"},{"type":"type","title":"Delimit.Schema.schema_options/0","doc":"Options for schema handling.\n\n* `:delimiter` - Field delimiter character (default: comma)\n* `:skip_lines` - Number of lines to skip at beginning of file\n* `:skip_while` - Function to determine which lines to skip\n* `:trim_fields` - Whether to trim whitespace from fields (default: true)\n* `:nil_on_empty` - Convert empty strings to nil (default: true)\n* `:line_ending` - Line ending character(s) for output\n* `:format` - Predefined format (`:csv`, `:tsv`, `:psv`) that sets appropriate options","ref":"Delimit.Schema.html#t:schema_options/0"},{"type":"type","title":"Delimit.Schema.t/0","doc":"Schema definition structure.\n\n* `:module` - The module associated with the schema\n* `:fields` - List of field definitions\n* `:options` - Additional options for the schema\n* `:embeds` - Map of module references for embedded schemas","ref":"Delimit.Schema.html#t:t/0"},{"type":"function","title":"Delimit.Schema.to_row/2","doc":"Converts a struct or map to a row of values based on the schema.","ref":"Delimit.Schema.html#to_row/2"},{"type":"function","title":"Parameters - Delimit.Schema.to_row/2","doc":"* `schema` - The schema definition\n  * `struct_or_map` - A struct or map containing field values","ref":"Delimit.Schema.html#to_row/2-parameters"},{"type":"function","title":"Returns - Delimit.Schema.to_row/2","doc":"* A list of field values","ref":"Delimit.Schema.html#to_row/2-returns"},{"type":"function","title":"Examples - Delimit.Schema.to_row/2","doc":"iex> schema = Delimit.Schema.new(MyApp.Person)\n    iex> schema = Delimit.Schema.add_field(schema, :name, :string)\n    iex> Delimit.Schema.to_row(schema, %{name: \"John Doe\"})\n    [\"John Doe\"]","ref":"Delimit.Schema.html#to_row/2-examples"},{"type":"function","title":"Delimit.Schema.to_struct/3","doc":"Converts a row of data to a struct based on the schema.","ref":"Delimit.Schema.html#to_struct/3"},{"type":"function","title":"Parameters - Delimit.Schema.to_struct/3","doc":"* `schema` - The schema definition\n  * `row` - A list of field values or a map of field name/values","ref":"Delimit.Schema.html#to_struct/3-parameters"},{"type":"function","title":"Returns - Delimit.Schema.to_struct/3","doc":"* A struct based on the schema with field values","ref":"Delimit.Schema.html#to_struct/3-returns"},{"type":"function","title":"Example - Delimit.Schema.to_struct/3","doc":"iex> schema = Delimit.Schema.new(MyApp.Person)\n    iex> schema = Delimit.Schema.add_field(schema, :name, :string)\n    iex> schema = Delimit.Schema.add_field(schema, :age, :integer)\n    iex> Delimit.Schema.to_struct(schema, [\"John Doe\", \"42\"])\n    %MyApp.Person{name: \"John Doe\", age: 42}","ref":"Delimit.Schema.html#to_struct/3-example"},{"type":"function","title":"Delimit.Schema.to_struct_with_headers/4","doc":"Converts a row of data to a struct based on the schema, using headers for field mapping.","ref":"Delimit.Schema.html#to_struct_with_headers/4"},{"type":"function","title":"Parameters - Delimit.Schema.to_struct_with_headers/4","doc":"* `schema` - The schema definition\n  * `row` - A list of field values \n  * `headers` - A list of header strings matching the row fields\n  * `opts` - Additional options for processing","ref":"Delimit.Schema.html#to_struct_with_headers/4-parameters"},{"type":"function","title":"Returns - Delimit.Schema.to_struct_with_headers/4","doc":"* A struct based on the schema with field values","ref":"Delimit.Schema.html#to_struct_with_headers/4-returns"},{"type":"function","title":"Delimit.Schema.type_to_typespec/1","doc":"Converts a field type to an Elixir typespec.\n\nThis function is used to convert field types to proper Elixir typespecs\nfor use in @type definitions.","ref":"Delimit.Schema.html#type_to_typespec/1"},{"type":"function","title":"Parameters - Delimit.Schema.type_to_typespec/1","doc":"* `type` - The field type or a tuple with more specific type information","ref":"Delimit.Schema.html#type_to_typespec/1-parameters"},{"type":"function","title":"Returns - Delimit.Schema.type_to_typespec/1","doc":"* An Elixir typespec expression","ref":"Delimit.Schema.html#type_to_typespec/1-returns"},{"type":"function","title":"Example - Delimit.Schema.type_to_typespec/1","doc":"iex> Delimit.Schema.type_to_typespec(:string)\n    quote do: String.t()\n    \n    iex> Delimit.Schema.type_to_typespec({:list, :string})\n    quote do: [String.t()]","ref":"Delimit.Schema.html#type_to_typespec/1-example"},{"type":"module","title":"Delimit.Writer","doc":"Functions for writing delimited data to files or strings.\n\nThis module provides functionality to write delimited data to files\nor strings based on schema definitions, supporting both single-write\nand streaming operations.","ref":"Delimit.Writer.html"},{"type":"function","title":"Delimit.Writer.stream_to_file/4","doc":"Streams delimited data to a file.","ref":"Delimit.Writer.html#stream_to_file/4"},{"type":"function","title":"Parameters - Delimit.Writer.stream_to_file/4","doc":"* `schema` - The schema definition\n  * `path` - Path to the output file\n  * `data_stream` - Stream of structs to write\n  * `opts` - Write options that override schema options","ref":"Delimit.Writer.html#stream_to_file/4-parameters"},{"type":"function","title":"Returns - Delimit.Writer.stream_to_file/4","doc":"* `:ok` on success","ref":"Delimit.Writer.html#stream_to_file/4-returns"},{"type":"function","title":"Example - Delimit.Writer.stream_to_file/4","doc":"iex> stream = Stream.map(1..1000, fn i -> %MyApp.Person{first_name: \"User\", last_name: \"User\", age: i} end)\n    iex> MyApp.Person.stream_to_file(\"people.csv\", stream)\n    :ok\n    \n    iex> stream = Stream.map(1..1000, fn i -> %MyApp.Person{first_name: \"User\", last_name: \"User\", age: i} end)\n    iex> MyApp.Person.stream_to_file(\"people.tsv\", stream, format: :tsv)\n    :ok","ref":"Delimit.Writer.html#stream_to_file/4-example"},{"type":"function","title":"Delimit.Writer.write_file/4","doc":"Writes delimited data to a file.","ref":"Delimit.Writer.html#write_file/4"},{"type":"function","title":"Parameters - Delimit.Writer.write_file/4","doc":"* `schema` - The schema definition\n  * `path` - Path to the output file\n  * `data` - List of structs to write\n  * `opts` - Write options that override schema options","ref":"Delimit.Writer.html#write_file/4-parameters"},{"type":"function","title":"Returns - Delimit.Writer.write_file/4","doc":"* `:ok` on success","ref":"Delimit.Writer.html#write_file/4-returns"},{"type":"function","title":"Example - Delimit.Writer.write_file/4","doc":"iex> people = [%MyApp.Person{first_name: \"John\", last_name: \"Doe\", age: 42}]\n    iex> MyApp.Person.write(\"people.csv\", people)\n    :ok","ref":"Delimit.Writer.html#write_file/4-example"},{"type":"type","title":"Delimit.Writer.write_options/0","doc":"Options for writing delimited data.\n\n* `:delimiter` - The field delimiter character (default: comma)\n* `:escape` - The escape character used for quotes (default: double-quote)\n* `:line_ending` - Line ending to use (default: system-dependent)\n* `:format` - Predefined format (`:csv`, `:tsv`, `:psv`) that sets appropriate options","ref":"Delimit.Writer.html#t:write_options/0"},{"type":"function","title":"Delimit.Writer.write_string/3","doc":"Writes delimited data to a string.","ref":"Delimit.Writer.html#write_string/3"},{"type":"function","title":"Parameters - Delimit.Writer.write_string/3","doc":"* `schema` - The schema definition\n  * `data` - List of structs to write\n  * `opts` - Write options that override schema options","ref":"Delimit.Writer.html#write_string/3-parameters"},{"type":"function","title":"Returns - Delimit.Writer.write_string/3","doc":"* String containing the delimited data","ref":"Delimit.Writer.html#write_string/3-returns"},{"type":"function","title":"Example - Delimit.Writer.write_string/3","doc":"iex> people = [%MyApp.Person{first_name: \"John\", last_name: \"Doe\", age: 42}]\n    iex> MyApp.Person.write_string(people)\n    \"first_name,last_name,age\\nJohn,Doe,42\\n\"\n    \n    iex> people = [%MyApp.Person{first_name: \"John\", last_name: \"Doe\", age: 42}]\n    iex> MyApp.Person.write_string(people, format: :tsv)\n    \"first_name\\tlast_name\\tage\\nJohn\\tDoe\\t42\\n\"","ref":"Delimit.Writer.html#write_string/3-example"},{"type":"module","title":"DelimitCommaParser","doc":"","ref":"DelimitCommaParser.html"},{"type":"function","title":"DelimitCommaParser.dump_to_iodata/1","doc":"Callback implementation for  NimbleCSV.dump_to_iodata/1 .","ref":"DelimitCommaParser.html#dump_to_iodata/1"},{"type":"function","title":"DelimitCommaParser.dump_to_stream/1","doc":"Callback implementation for  NimbleCSV.dump_to_stream/1 .","ref":"DelimitCommaParser.html#dump_to_stream/1"},{"type":"function","title":"DelimitCommaParser.parse_enumerable/2","doc":"Callback implementation for  NimbleCSV.parse_enumerable/2 .","ref":"DelimitCommaParser.html#parse_enumerable/2"},{"type":"function","title":"DelimitCommaParser.parse_stream/2","doc":"Callback implementation for  NimbleCSV.parse_stream/2 .","ref":"DelimitCommaParser.html#parse_stream/2"},{"type":"function","title":"DelimitCommaParser.parse_string/2","doc":"Callback implementation for  NimbleCSV.parse_string/2 .","ref":"DelimitCommaParser.html#parse_string/2"},{"type":"function","title":"DelimitCommaParser.to_line_stream/1","doc":"Callback implementation for  NimbleCSV.to_line_stream/1 .","ref":"DelimitCommaParser.html#to_line_stream/1"},{"type":"module","title":"DelimitPipeParser","doc":"","ref":"DelimitPipeParser.html"},{"type":"function","title":"DelimitPipeParser.dump_to_iodata/1","doc":"Callback implementation for  NimbleCSV.dump_to_iodata/1 .","ref":"DelimitPipeParser.html#dump_to_iodata/1"},{"type":"function","title":"DelimitPipeParser.dump_to_stream/1","doc":"Callback implementation for  NimbleCSV.dump_to_stream/1 .","ref":"DelimitPipeParser.html#dump_to_stream/1"},{"type":"function","title":"DelimitPipeParser.parse_enumerable/2","doc":"Callback implementation for  NimbleCSV.parse_enumerable/2 .","ref":"DelimitPipeParser.html#parse_enumerable/2"},{"type":"function","title":"DelimitPipeParser.parse_stream/2","doc":"Callback implementation for  NimbleCSV.parse_stream/2 .","ref":"DelimitPipeParser.html#parse_stream/2"},{"type":"function","title":"DelimitPipeParser.parse_string/2","doc":"Callback implementation for  NimbleCSV.parse_string/2 .","ref":"DelimitPipeParser.html#parse_string/2"},{"type":"function","title":"DelimitPipeParser.to_line_stream/1","doc":"Callback implementation for  NimbleCSV.to_line_stream/1 .","ref":"DelimitPipeParser.html#to_line_stream/1"},{"type":"module","title":"DelimitSemicolonParser","doc":"","ref":"DelimitSemicolonParser.html"},{"type":"function","title":"DelimitSemicolonParser.dump_to_iodata/1","doc":"Callback implementation for  NimbleCSV.dump_to_iodata/1 .","ref":"DelimitSemicolonParser.html#dump_to_iodata/1"},{"type":"function","title":"DelimitSemicolonParser.dump_to_stream/1","doc":"Callback implementation for  NimbleCSV.dump_to_stream/1 .","ref":"DelimitSemicolonParser.html#dump_to_stream/1"},{"type":"function","title":"DelimitSemicolonParser.parse_enumerable/2","doc":"Callback implementation for  NimbleCSV.parse_enumerable/2 .","ref":"DelimitSemicolonParser.html#parse_enumerable/2"},{"type":"function","title":"DelimitSemicolonParser.parse_stream/2","doc":"Callback implementation for  NimbleCSV.parse_stream/2 .","ref":"DelimitSemicolonParser.html#parse_stream/2"},{"type":"function","title":"DelimitSemicolonParser.parse_string/2","doc":"Callback implementation for  NimbleCSV.parse_string/2 .","ref":"DelimitSemicolonParser.html#parse_string/2"},{"type":"function","title":"DelimitSemicolonParser.to_line_stream/1","doc":"Callback implementation for  NimbleCSV.to_line_stream/1 .","ref":"DelimitSemicolonParser.html#to_line_stream/1"},{"type":"module","title":"DelimitTabParser","doc":"","ref":"DelimitTabParser.html"},{"type":"function","title":"DelimitTabParser.dump_to_iodata/1","doc":"Callback implementation for  NimbleCSV.dump_to_iodata/1 .","ref":"DelimitTabParser.html#dump_to_iodata/1"},{"type":"function","title":"DelimitTabParser.dump_to_stream/1","doc":"Callback implementation for  NimbleCSV.dump_to_stream/1 .","ref":"DelimitTabParser.html#dump_to_stream/1"},{"type":"function","title":"DelimitTabParser.parse_enumerable/2","doc":"Callback implementation for  NimbleCSV.parse_enumerable/2 .","ref":"DelimitTabParser.html#parse_enumerable/2"},{"type":"function","title":"DelimitTabParser.parse_stream/2","doc":"Callback implementation for  NimbleCSV.parse_stream/2 .","ref":"DelimitTabParser.html#parse_stream/2"},{"type":"function","title":"DelimitTabParser.parse_string/2","doc":"Callback implementation for  NimbleCSV.parse_string/2 .","ref":"DelimitTabParser.html#parse_string/2"},{"type":"function","title":"DelimitTabParser.to_line_stream/1","doc":"Callback implementation for  NimbleCSV.to_line_stream/1 .","ref":"DelimitTabParser.html#to_line_stream/1"},{"type":"extras","title":"Delimit","doc":"# Delimit\n\n[![Hex.pm Version](https://img.shields.io/hexpm/v/delimit.svg)](https://hex.pm/packages/delimit)\n[![Hex.pm License](https://img.shields.io/hexpm/l/delimit.svg)](https://github.com/jcowgar/delimit/blob/main/LICENSE)\n\nDelimit is a powerful yet elegant library for reading and writing delimited data files (CSV, TSV, PSV, SSV) in Elixir. Inspired by Ecto, it allows you to define schemas for your delimited data, providing strong typing with structs, validation, and transformation capabilities. By defining the structure of your data, Delimit enables type-safe parsing and generation with minimal boilerplate code.","ref":"readme.html"},{"type":"extras","title":"Features - Delimit","doc":"- **Schema-based approach**: Define the structure of your delimited files using Ecto-like schemas\n- **Strong typing with structs**: Convert between string values and proper Elixir types in type-safe structs\n- **Full TypeSpecs**: Automatically generated type specifications for your schemas\n- **Streaming support**: Process large files efficiently with Elixir streams\n- **Customizable parsing**: Configure delimiters, headers, type conversion, and more\n- **Embedded schemas**: Nest schemas for complex data structures\n- **Custom transformations**: Add your own read/write functions for special data formats\n- **Memory efficient**: Stream large files without loading everything into memory","ref":"readme.html#features"},{"type":"extras","title":"Installation - Delimit","doc":"Add `delimit` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:delimit, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen fetch your dependencies:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - Delimit","doc":"","ref":"readme.html#quick-start"},{"type":"extras","title":"Define a schema - Delimit","doc":"Define a schema that represents the structure of your delimited file:\n\n```elixir\ndefmodule MyApp.Person do\n  use Delimit\n\n  layout do\n    field :first_name, :string\n    field :last_name, :string\n    field :age, :integer\n    field :salary, :float\n    field :birthday, :date, format: \"{YYYY}-{0M}-{0D}\"\n    field :active, :boolean\n    field :notes, :string, nil_on_empty: true\n  end\nend\n```\n\nThis automatically creates a struct with type specifications:\n\n```elixir\n@type t :: %__MODULE__{\n  first_name: String.t(),\n  last_name: String.t(),\n  age: integer(),\n  salary: float(),\n  birthday: Date.t(),\n  active: boolean(),\n  notes: String.t()\n}\n```","ref":"readme.html#define-a-schema"},{"type":"extras","title":"Reading data - Delimit","doc":"Read data from a file:\n\n```elixir\n# Read all records at once - returns a list of structs\npeople = MyApp.Person.read(\"people.csv\")\nfirst_person = List.first(people) # returns a %MyApp.Person{} struct\n\n# Stream records for better memory efficiency\npeople_stream =\n  \"large_file.csv\"\n  |> MyApp.Person.stream()\n  |> Stream.filter(fn person -> person.age > 30 end)\n  |> Stream.map(fn person -> %{person | salary: person.salary * 1.1} end)\n  |> Enum.to_list()\n\n# Read from a string\ncsv_data = \"first_name,last_name,age\\nJohn,Doe,42\"\npeople = MyApp.Person.read_string(csv_data)\n```","ref":"readme.html#reading-data"},{"type":"extras","title":"Writing data - Delimit","doc":"Write data to a file:\n\n```elixir\npeople = [\n  %MyApp.Person{first_name: \"John\", last_name: \"Doe\", age: 42,\n    salary: 50000.0, birthday: ~D[1980-01-15], active: true, notes: \"Senior developer\"},\n  %MyApp.Person{first_name: \"Jane\", last_name: \"Smith\", age: 35,\n    salary: 60000.0, birthday: ~D[1987-05-22], active: true, notes: nil}\n]\n\n# Write all records at once\n:ok = MyApp.Person.write(\"people.csv\", people)\n\n# Write to a string\ncsv_string = MyApp.Person.write_string(people)\n\n# Stream data to a file (memory efficient)\nstream = Stream.map(1..1000, fn i ->\n  %MyApp.Person{\n    first_name: \"User#{i}\",\n    last_name: \"Test\",\n    age: 20 + rem(i, 50),\n    salary: 30_000.0 + (i * 100),\n    birthday: Date.add(~D[2000-01-01], i),\n    active: rem(i, 2) == 0,\n    notes: \"Generated user #{i}\"\n  }\nend)\n\n:ok = MyApp.Person.stream_to_file(\"users.csv\", stream)\n```","ref":"readme.html#writing-data"},{"type":"extras","title":"Field Types - Delimit","doc":"Delimit supports the following field types:\n\n| Type        | Description            | Example                        |\n| ----------- | ---------------------- | ------------------------------ |\n| `:string`   | Basic string values    | `field :name, :string`         |\n| `:integer`  | Integer numbers        | `field :age, :integer`         |\n| `:float`    | Floating point numbers | `field :salary, :float`        |\n| `:boolean`  | Boolean values         | `field :active, :boolean`      |\n| `:date`     | Date values            | `field :birthday, :date`       |\n| `:datetime` | DateTime values        | `field :created_at, :datetime` |","ref":"readme.html#field-types"},{"type":"extras","title":"Field Options - Delimit","doc":"Each field can have additional options:\n\n> **Note:** Date and DateTime fields use [Timex](https://hexdocs.pm/timex/Timex.Format.DateTime.Formatters.Default.html) format patterns for parsing and formatting.\n\n```elixir\n# Default value when field is missing\nfield :age, :integer, default: 0\n\n# Custom header name in CSV file\nfield :email, :string, label: \"contact_email\"\n\n# Format for date/datetime fields (using Timex format patterns)\nfield :birthday, :date, format: \"{0M}/{0D}/{YYYY}\"\n\n# Convert empty strings to nil\nfield :notes, :string, nil_on_empty: true\n\n# Custom values for boolean fields\nfield :status, :boolean, true_values: [\"Y\", \"Yes\"], false_values: [\"N\", \"No\"]\n\n# Custom conversion functions with explicit struct type\nfield :tags, :string,\n  read_fn: &String.split(&1, \"|\"),\n  write_fn: &Enum.join(&1, \"|\"),\n  struct_type: {:list, :string}\n```","ref":"readme.html#field-options"},{"type":"extras","title":"Advanced Usage - Delimit","doc":"This section covers more advanced features and techniques for getting the most out of Delimit.","ref":"readme.html#advanced-usage"},{"type":"extras","title":"Type Specifications - Delimit","doc":"Delimit automatically generates typespecs for your schemas, including support for complex field types:\n\n```elixir\ndefmodule MyApp.User do\n  use Delimit\n\n  layout do\n    field :name, :string\n    # File contains comma-separated tags, but in memory it's a list\n    field :tags, :string,\n      read_fn: &String.split(&1, \",\"),\n      write_fn: &Enum.join(&1, \",\"),\n      struct_type: {:list, :string}\n\n    # Map type with string keys and integer values\n    field :scores, :string,\n      read_fn: &parse_scores/1,\n      write_fn: &serialize_scores/1,\n      struct_type: {:map, :string, :integer}\n  end\n\n  defp parse_scores(str), do: # Parse string to map\n  defp serialize_scores(map), do: # Convert map to string\nend\n```","ref":"readme.html#type-specifications"},{"type":"extras","title":"Embedded Schemas - Delimit","doc":"You can nest schemas using the `embeds_one` macro:\n\n```elixir\ndefmodule MyApp.Address do\n  use Delimit\n\n  layout do\n    field :street, :string\n    field :city, :string\n    field :state, :string\n    field :postal_code, :string\n  end\nend\n\ndefmodule MyApp.Customer do\n  use Delimit\n\n  layout do\n    field :name, :string\n    field :email, :string\n    embeds_one :address, MyApp.Address\n    embeds_one :billing_address, MyApp.Address, prefix: \"billing_\"\n  end\nend\n\n# This will handle headers like:\n# name,email,street,city,state,postal_code,billing_street,billing_city,billing_state,billing_postal_code\n#\n# And create structs like:\n# %MyApp.Customer{\n#   name: \"John Doe\",\n#   email: \"john@example.com\",\n#   address: %MyApp.Address{street: \"123 Main St\", ...},\n#   billing_address: %MyApp.Address{street: \"456 Billing St\", ...}\n# }\n```","ref":"readme.html#embedded-schemas"},{"type":"extras","title":"Using Standard Formats - Delimit","doc":"Delimit provides built-in support for common file formats:\n\n```elixir\n# Read tab-separated values with the format option\npeople = MyApp.Person.read(\"people.tsv\", format: :tsv)\n\n# Read comma-separated values (also the default)\npeople = MyApp.Person.read(\"people.csv\", format: :csv)\n\n# Write pipe-separated values\n:ok = MyApp.Person.write(\"people.psv\", people, format: :psv)\n```\n\nSupported formats include:\n\n- `:csv` - Comma-separated values with double-quote escaping\n- `:tsv` - Tab-separated values with double-quote escaping\n- `:psv` - Pipe-separated values with double-quote escaping\n- `:ssv` - Semi-colon-separated values with double-quote escaping","ref":"readme.html#using-standard-formats"},{"type":"extras","title":"Parser Configuration Options - Delimit","doc":"Delimit provides several customization options for parsing and generating delimited files:\n\n#### Delimiter Options\n\n```elixir\n# Read tab-separated values with explicit delimiter\npeople = MyApp.Person.read(\"people.tsv\", delimiter: \"\\t\")\n\n# Write pipe-separated values with explicit delimiter\n:ok = MyApp.Person.write(\"people.psv\", people, delimiter: \"|\")\n\n# Use a specific escape character (default is double-quote)\npeople = MyApp.Person.read(\"people.csv\", escape: \"\\\"\")\n\n# Set line ending for generated files (default is \\n)\n:ok = MyApp.Person.write(\"people.csv\", people, line_ending: \"\\r\\n\")\n```\n\n#### Headers and Content Processing\n\n```elixir\n# Control whether headers are included (default is true)\npeople = MyApp.Person.read(\"people.csv\", headers: false)\n:ok = MyApp.Person.write(\"people.csv\", people, headers: false)\n\n# Skip a specific number of lines at the beginning of a file\npeople = MyApp.Person.read(\"people.csv\", skip_lines: 3)\n\n# Skip lines dynamically based on content (like comments)\npeople = MyApp.Person.read(\"people.csv\",\n  skip_while: fn line -> String.starts_with?(line, \"#\") end)\n\n# Control whether to trim whitespace from fields\npeople = MyApp.Person.read(\"people.csv\", trim_fields: true)\n```\n\n#### Combining Multiple Options\n\nOptions can be combined for complete customization:\n\n```elixir\n# Multiple options can be combined\npeople = MyApp.Person.read(\"people.csv\",\n  delimiter: \";\",\n  escape: \"\\\"\",\n  skip_lines: 2,\n  trim_fields: true,\n  headers: true\n)\n```","ref":"readme.html#parser-configuration-options"},{"type":"extras","title":"License - Delimit","doc":"This project is licensed under the LGPL-3 License - see the LICENSE file for details.","ref":"readme.html#license"},{"type":"extras","title":"Contributing - Delimit","doc":"Contributions are welcome! Please feel free to submit a Pull Request.","ref":"readme.html#contributing"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.2.0 (2025-05-21) - Changelog","doc":"","ref":"changelog.html#0-2-0-2025-05-21"},{"type":"extras","title":"Fixes - Changelog","doc":"- Do not double skip headers","ref":"changelog.html#fixes"},{"type":"extras","title":"Other - Changelog","doc":"- Simplified code to eliminate pre-processing\n- More appropriate empty row/value detection\n- Rely on layout for field mapping, not layout AND header content","ref":"changelog.html#other"},{"type":"extras","title":"0.1.0 (2025-05-12) - Changelog","doc":"- Initial release","ref":"changelog.html#0-1-0-2025-05-12"},{"type":"extras","title":"LICENSE","doc":"GNU LESSER GENERAL PUBLIC LICENSE\n                       Version 3, 29 June 2007\n\n Copyright (C) 2007 Free Software Foundation, Inc.  \n Everyone is permitted to copy and distribute verbatim copies\n of this license document, but changing it is not allowed.\n\n\n  This version of the GNU Lesser General Public License incorporates\nthe terms and conditions of version 3 of the GNU General Public\nLicense, supplemented by the additional permissions listed below.\n\n  0. Additional Definitions.\n\n  As used herein, \"this License\" refers to version 3 of the GNU Lesser\nGeneral Public License, and the \"GNU GPL\" refers to version 3 of the GNU\nGeneral Public License.\n\n  \"The Library\" refers to a covered work governed by this License,\nother than an Application or a Combined Work as defined below.\n\n  An \"Application\" is any work that makes use of an interface provided\nby the Library, but which is not otherwise based on the Library.\nDefining a subclass of a class defined by the Library is deemed a mode\nof using an interface provided by the Library.\n\n  A \"Combined Work\" is a work produced by combining or linking an\nApplication with the Library.  The particular version of the Library\nwith which the Combined Work was made is also called the \"Linked\nVersion\".\n\n  The \"Minimal Corresponding Source\" for a Combined Work means the\nCorresponding Source for the Combined Work, excluding any source code\nfor portions of the Combined Work that, considered in isolation, are\nbased on the Application, and not on the Linked Version.\n\n  The \"Corresponding Application Code\" for a Combined Work means the\nobject code and/or source code for the Application, including any data\nand utility programs needed for reproducing the Combined Work from the\nApplication, but excluding the System Libraries of the Combined Work.\n\n  1. Exception to Section 3 of the GNU GPL.\n\n  You may convey a covered work under sections 3 and 4 of this License\nwithout being bound by section 3 of the GNU GPL.\n\n  2. Conveying Modified Versions.\n\n  If you modify a copy of the Library, and, in your modifications, a\nfacility refers to a function or data to be supplied by an Application\nthat uses the facility (other than as an argument passed when the\nfacility is invoked), then you may convey a copy of the modified\nversion:\n\n   a) under this License, provided that you make a good faith effort to\n   ensure that, in the event an Application does not supply the\n   function or data, the facility still operates, and performs\n   whatever part of its purpose remains meaningful, or\n\n   b) under the GNU GPL, with none of the additional permissions of\n   this License applicable to that copy.\n\n  3. Object Code Incorporating Material from Library Header Files.\n\n  The object code form of an Application may incorporate material from\na header file that is part of the Library.  You may convey such object\ncode under terms of your choice, provided that, if the incorporated\nmaterial is not limited to numerical parameters, data structure\nlayouts and accessors, or small macros, inline functions and templates\n(ten or fewer lines in length), you do both of the following:\n\n   a) Give prominent notice with each copy of the object code that the\n   Library is used in it and that the Library and its use are\n   covered by this License.\n\n   b) Accompany the object code with a copy of the GNU GPL and this license\n   document.\n\n  4. Combined Works.\n\n  You may convey a Combined Work under terms of your choice that,\ntaken together, effectively do not restrict modification of the\nportions of the Library contained in the Combined Work and reverse\nengineering for debugging such modifications, if you also do each of\nthe following:\n\n   a) Give prominent notice with each copy of the Combined Work that\n   the Library is used in it and that the Library and its use are\n   covered by this License.\n\n   b) Accompany the Combined Work with a copy of the GNU GPL and this license\n   document.\n\n   c) For a Combined Work that displays copyright notices during\n   execution, include the copyright notice for the Library among\n   these notices, as well as a reference directing the user to the\n   copies of the GNU GPL and this license document.\n\n   d) Do one of the following:\n\n       0) Convey the Minimal Corresponding Source under the terms of this\n       License, and the Corresponding Application Code in a form\n       suitable for, and under terms that permit, the user to\n       recombine or relink the Application with a modified version of\n       the Linked Version to produce a modified Combined Work, in the\n       manner specified by section 6 of the GNU GPL for conveying\n       Corresponding Source.\n\n       1) Use a suitable shared library mechanism for linking with the\n       Library.  A suitable mechanism is one that (a) uses at run time\n       a copy of the Library already present on the user's computer\n       system, and (b) will operate properly with a modified version\n       of the Library that is interface-compatible with the Linked\n       Version.\n\n   e) Provide Installation Information, but only if you would otherwise\n   be required to provide such information under section 6 of the\n   GNU GPL, and only to the extent that such information is\n   necessary to install and execute a modified version of the\n   Combined Work produced by recombining or relinking the\n   Application with a modified version of the Linked Version. (If\n   you use option 4d0, the Installation Information must accompany\n   the Minimal Corresponding Source and Corresponding Application\n   Code. If you use option 4d1, you must provide the Installation\n   Information in the manner specified by section 6 of the GNU GPL\n   for conveying Corresponding Source.)\n\n  5. Combined Libraries.\n\n  You may place library facilities that are a work based on the\nLibrary side by side in a single library together with other library\nfacilities that are not Applications and are not covered by this\nLicense, and convey such a combined library under terms of your\nchoice, if you do both of the following:\n\n   a) Accompany the combined library with a copy of the same work based\n   on the Library, uncombined with any other library facilities,\n   conveyed under the terms of this License.\n\n   b) Give prominent notice with the combined library that part of it\n   is a work based on the Library, and explaining where to find the\n   accompanying uncombined form of the same work.\n\n  6. Revised Versions of the GNU Lesser General Public License.\n\n  The Free Software Foundation may publish revised and/or new versions\nof the GNU Lesser General Public License from time to time. Such new\nversions will be similar in spirit to the present version, but may\ndiffer in detail to address new problems or concerns.\n\n  Each version is given a distinguishing version number. If the\nLibrary as you received it specifies that a certain numbered version\nof the GNU Lesser General Public License \"or any later version\"\napplies to it, you have the option of following the terms and\nconditions either of that published version or of any later version\npublished by the Free Software Foundation. If the Library as you\nreceived it does not specify a version number of the GNU Lesser\nGeneral Public License, you may choose any version of the GNU Lesser\nGeneral Public License ever published by the Free Software Foundation.\n\n  If the Library as you received it specifies that a proxy can decide\nwhether future versions of the GNU Lesser General Public License shall\napply, that proxy's public statement of acceptance of any version is\npermanent authorization for you to choose that version for the\nLibrary.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}